@@ -3,35 +3,27 @@
 # This program is dedicated to the public domain under the CC0 license.
 
 """
-Simple Bot to reply to Telegram messages.
-
-First, a few handler functions are defined. Then, those functions are passed to
-the Dispatcher and registered at their respective places.
-Then, the bot is started and runs until we press Ctrl-C on the command line.
-
-Usage:
-Basic Echobot example, repeats messages.
-Press Ctrl-C on the command line or send a signal to the process to stop the
-bot.
+Tabayyun bot on Telegram
 """
 
 import logging
 import os
+import sys
 
 from telegram import Update, ForceReply
 from telegram.error import BadRequest
 from telegram.ext import Updater, CommandHandler, MessageHandler, Filters, CallbackContext
 
-from src.dataclasses.chat import Chat
+from src.config.env import EnvConfig as Config
+from src.dataclasses.model import Chat
 from src.service.server import Server
 
 # Enable logging
 logging.basicConfig(
-    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s', level=logging.DEBUG
+    format=Config.LOG_FORMAT, level=Config.LOG_LEVEL
 )
 
-logger = logging.getLogger(__name__)
-server = Server()
+SERVER = Server()
 
 
 # Define a few command handlers. These usually take the two arguments update and
@@ -48,7 +40,8 @@ def start_command(update: Update, context: CallbackContext = None) -> None:
 def help_command(update: Update, context: CallbackContext = None) -> None:
     """Send a message when the command /help is issued."""
     update.message.reply_text(
-        """Petunjuk penggunaan :
+        """📜 Petunjuk penggunaan :
+        
 Silahkan masukan/forward artikel atau postingan di sini, maka bot akan memulai menganalisa apakah postingan/artikel tersebut mengandung informasi yang valid atau tidak (Hoax). 
 Kamu juga bisa masukan topik apapun untuk dianalisa apakah saat ini ada berita atau hoax terkait topik tersebut
         """)
@@ -60,27 +53,39 @@ def contact_command(update: Update, context: CallbackContext = None) -> None:
 
 
 def handler(update: Update, context: CallbackContext = None) -> None:
-    """Echo the user message."""
+    """Method for handling messages"""
+    if update.message.text[0] == "!":
+        reply = SERVER.magic_keyword(update.message.text)
+        update.message.reply_text(reply)
+        return
+
+    if update.message.from_user.username:
+        sender_id = update.message.from_user.username
+    else:
+        sender_id = "unknown"
     chat = Chat(
         chat_id=update.message.chat_id,
-        sender_id=update.message.from_user.username,
+        sender_id=sender_id,
         sender=update.message.from_user.first_name,
         str_message=update.message.text
     )
-    svr = Server()
+    reply = SERVER.handler(chat)
     try:
-        update.message.reply_text(svr.handler(chat))
+        logging.debug("Sending message...")
+        update.message.reply_text(reply)
     except BadRequest as br:
         update.message.reply_text("Kata/Kalimat terlalu umum, silahkan masukan artikel/topik yang hendak dianalisa!")
+    logging.debug("Message sent..")
 
 
-def start_bot() -> None:
+def start_bot():
     """Start the bot."""
     # Create the Updater and pass it your bot's token.
     if os.environ.get('BOT_TOKEN'):
         token = os.environ['BOT_TOKEN']
     else:
-        token = "1864795084:AAGbZZmCF3oK7q5opPZUatLw3KzguMH7fYU"
+        logging.error("BOT_TOKEN is not set!")
+        return
 
     updater = Updater(token)
     # Get the dispatcher to register handlers
